@@ -7,6 +7,8 @@ def main(verbose : "Display extra information about [[tags]] (not yet implemente
             all : "Concatenate all results into one .md file with shared [[tags]] (not yet implemented)"=False,
             *files):
 
+    if len(files == 0):
+        return
 
     for file in files:
         assert file.endswith(".txt"), "One or more of your files is not a .txt file"
@@ -57,5 +59,5 @@ def main(verbose : "Display extra information about [[tags]] (not yet implemente
 
 
 
-            print("\nAnalyzed {0} files, found {1} named entities, wrote {2} file(s)\n".format(str(numFiles), str(totalEntityCount), str(writtenFiles)))
+    print("\nAnalyzed {0} files, found {1} named entities, wrote {2} file(s)\n".format(str(numFiles), str(totalEntityCount), str(writtenFiles)))
 argh.dispatch_command(main)
